@@ -486,7 +486,7 @@ class Examples:
 
     expected_procedures1 = Procedures.construct(
         describedBy=described_by,
-        schema_version="0.6.2",
+        schema_version="0.7.0",
         subject_id="650102",
         subject_procedures=expected_subject_procedures1,
     )
@@ -508,6 +508,9 @@ class Examples:
             procedure_type="Iontophoresis",
             injection_current=5.0,
             alternating_current="7/7",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            instrument_id="Ionto #1",
+            recovery_time=None,
         ),
         # from list item 9
         Headframe.construct(
@@ -522,6 +525,24 @@ class Examples:
             headframe_part_number="0160-100-10",
             well_type="Mesoscope",
             well_part_number="0160-200-20",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+        ),
+        Craniotomy.construct(
+            start_date=datetime.date(2022, 1, 3),
+            end_date=datetime.date(2022, 1, 3),
+            experimenter_full_name="NSB-187",
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
+            procedure_type="Craniotomy",
+            craniotomy_type="5mm",
+            craniotomy_size=5.0,
+            craniotomy_hemisphere=None,
+            craniotomy_coordinates_ml=None,
+            craniotomy_coordinates_ap=None,
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=30,
+            workstation_id="SWS 5",
         ),
         # from list item 10
         Craniotomy.construct(
@@ -537,6 +558,8 @@ class Examples:
             craniotomy_hemisphere=None,
             craniotomy_coordinates_ml=None,
             craniotomy_coordinates_ap=None,
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         # from list item 11
         Headframe.construct(
@@ -551,6 +574,7 @@ class Examples:
             headframe_part_number="0160-100-42",
             well_type="Neuropixel",
             well_part_number="0160-200-36",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         NanojectInjection.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -565,20 +589,26 @@ class Examples:
             injection_angle=None,
             procedure_type="Nanoject (Pressure)",
             injection_volume=500.0,
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         NanojectInjection.construct(
-            start_date=datetime.date(2022, 1, 3),
-            end_date=datetime.date(2022, 1, 3),
+            start_date=None,
+            end_date=None,
             experimenter_full_name="NSB-187",
             iacuc_protocol="2103",
-            animal_weight_prior=25.2,
-            animal_weight_post=28.2,
+            animal_weight_prior=28.2,
+            animal_weight_post=None,
             injection_coordinate_ml=3.0,
             injection_coordinate_ap=-2.45,
             injection_coordinate_depth=None,
             injection_angle=None,
             procedure_type="Nanoject (Pressure)",
             injection_volume=600.0,
+            anaesthesia=Anaesthetic(
+                type="isoflurane", duration=120, level=2.5
+            ),
+            recovery_time=30,
         ),
         NanojectInjection.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -593,6 +623,8 @@ class Examples:
             injection_coordinate_depth=None,
             injection_angle=None,
             injection_volume=600.0,
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         # from list item 14
         Headframe.construct(
@@ -607,6 +639,7 @@ class Examples:
             headframe_part_number="0160-100-46",
             well_type="WHC NP",
             well_part_number="0160-055-08",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         NanojectInjection.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -623,6 +656,8 @@ class Examples:
             procedure_type="Nanoject (Pressure)",
             injection_volume=600.0,
             notes=None,
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         FiberImplant.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -640,6 +675,7 @@ class Examples:
                 stereotactic_coordinate_dv=-2.95,
                 angle=0.0,
             ),
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         IontophoresisInjection.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -657,6 +693,8 @@ class Examples:
             injection_angle=0.0,
             injection_current=None,
             alternating_current="7/7",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         FiberImplant.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -674,6 +712,7 @@ class Examples:
                 stereotactic_coordinate_dv=-1.05,
                 angle=0.0,
             ),
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         IontophoresisInjection.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -690,6 +729,8 @@ class Examples:
             procedure_type="Iontophoresis",
             injection_current=5.0,
             alternating_current="7/7",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         FiberImplant.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -706,6 +747,7 @@ class Examples:
                 stereotactic_coordinate_dv=-1.85,
                 angle=0.0,
             ),
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         IontophoresisInjection.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -722,6 +764,8 @@ class Examples:
             procedure_type="Iontophoresis",
             injection_current=5.0,
             alternating_current="7/7",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
+            recovery_time=25,
         ),
         FiberImplant.construct(
             start_date=datetime.date(2022, 1, 3),
@@ -738,6 +782,7 @@ class Examples:
                 stereotactic_coordinate_dv=-1.8,
                 angle=0.0,
             ),
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         # from list item 15
         Headframe.construct(
@@ -752,6 +797,7 @@ class Examples:
             headframe_part_number="0160-100-51",
             well_type="Scientifica (CAM)",
             well_part_number="Rev A",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         # from list item 16
         Headframe.construct(
@@ -766,6 +812,7 @@ class Examples:
             headframe_part_number=None,
             well_type="No Well",
             well_part_number=None,
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
         # from list item 17
         Headframe.construct(
@@ -780,8 +827,9 @@ class Examples:
             headframe_part_number="0160-100-45",
             well_type="WHC 2P",
             well_part_number="0160-200-62",
+            anaesthesia=Anaesthetic(type="isoflurane", duration=90, level=2.0),
         ),
-        # from list item 13
+        # # from list item 13
         SubjectProcedure.construct(
             start_date=datetime.date(2022, 1, 3),
             end_date=datetime.date(2022, 1, 3),
@@ -795,7 +843,7 @@ class Examples:
 
     expected_procedures_2023_1 = Procedures.construct(
         describedBy=described_by,
-        schema_version="0.5.4",
+        schema_version="0.7.0",
         subject_id="650102",
         subject_procedures=expected_subject_procedures2,
     )
